@@ -17,6 +17,7 @@ def load(
     load_administered: Optional[bool] = True,
     wildcard_code: Optional[bool] = True,
     n_rows: Optional[int] = None,
+    exclude_atc_codes: Optional[list[str]] = None,
 ) -> pd.DataFrame:
     """Load medications. Aggregates prescribed/administered if both true. If
     wildcard_atc_code, match from atc_code*. Aggregates all that match. Beware
@@ -34,7 +35,8 @@ def load(
             Defaults to True.
         wildcard_code (bool, optional): Whether to match on atc_code* or
             atc_code.
-        n_rows (int, optional): Number of rows to return. Defaults to None.
+        n_rows (int, optional): Number of rows to return. Defaults to None, in which case all rows are returned.
+        exclude_atc_codes (list[str], optional): Drop rows if atc_code is a direct match to any of these. Defaults to None.
 
     Returns:
         pd.DataFrame: Cols: dw_ek_borger, timestamp, {atc_code_prefix}_value = 1
@@ -60,6 +62,7 @@ def load(
             output_col_name=output_col_name,
             match_with_wildcard=wildcard_code,
             n_rows=n_rows,
+            exclude_codes=exclude_atc_codes,
             load_diagnoses=False,
         )
 
@@ -74,6 +77,7 @@ def load(
             output_col_name=output_col_name,
             match_with_wildcard=wildcard_code,
             n_rows=n_rows,
+            exclude_codes=exclude_atc_codes,
             load_diagnoses=False,
         )
         df = pd.concat([df, df_medication_administered])
@@ -136,12 +140,14 @@ def concat_medications(
 # data_loaders primarly used in psychiatry
 @data_loaders.register("antipsychotics")
 def antipsychotics(n_rows: Optional[int] = None) -> pd.DataFrame:
+    """All antipsyhotics, except Lithium. Lithium is typically considered a mood stabilizer, not an antipsychotic."""
     return load(
         atc_code="N05A",
         load_prescribed=True,
         load_administered=True,
         wildcard_code=True,
         n_rows=n_rows,
+        exclude_atc_codes=["N05AN01"],
     )
 
 
@@ -191,6 +197,24 @@ def second_gen_antipsychotics(n_rows: Optional[int] = None) -> pd.DataFrame:
     )
 
 
+@data_loaders.register("top_10_weight_gaining_antipsychotics")
+def top_10_weight_gaining_antipsychotics(n_rows: Optional[int] = None) -> pd.DataFrame:
+    """Top 10 weight gaining antipsychotics based on Huhn et al. 2019. Only 5 of them are marketed in Denmark."""
+    return load(
+        atc_code=[
+            "N05AH03",
+            "N05AE03",
+            "N05AH04",
+            "N05AX13",
+            "N05AX08",
+        ],
+        load_prescribed=True,
+        load_administered=True,
+        wildcard_code=False,
+        n_rows=n_rows,
+    )
+
+
 @data_loaders.register("olanzapine")
 def olanzapine(n_rows: Optional[int] = None) -> pd.DataFrame:
     return load(
@@ -224,6 +248,41 @@ def anxiolytics(n_rows: Optional[int] = None) -> pd.DataFrame:
     )
 
 
+@data_loaders.register("benzodiazepines")
+def benzodiazepines(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="N05BA",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("benzodiazepine_related_sleeping_agents")
+def benzodiazepine_related_sleeping_agents(
+    n_rows: Optional[int] = None,
+) -> pd.DataFrame:
+    return load(
+        atc_code=["N05CF01", "N05CF02"],
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("pregabaline")
+def pregabaline(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="N03AX16",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
 @data_loaders.register("hypnotics and sedatives")
 def hypnotics(n_rows: Optional[int] = None) -> pd.DataFrame:
     return load(
@@ -250,10 +309,10 @@ def antidepressives(n_rows: Optional[int] = None) -> pd.DataFrame:
 @data_loaders.register("ssri")
 def ssri(n_rows: Optional[int] = None) -> pd.DataFrame:
     return load(
-        atc_code=["N06AB10", "N06AB04", "N06AB08", "N06AB03", "N06AB05", "N06AB06"],
+        atc_code="N06AB",
         load_prescribed=True,
         load_administered=True,
-        wildcard_code=False,
+        wildcard_code=True,
         n_rows=n_rows,
     )
 
@@ -270,14 +329,25 @@ def snri(n_rows: Optional[int] = None) -> pd.DataFrame:
     )
 
 
-# TCAs [amitryptilin, clomipramin, imipramin, nortriptyline, dosulepin]
+# TCAs
 @data_loaders.register("tca")
 def tca(n_rows: Optional[int] = None) -> pd.DataFrame:
     return load(
-        atc_code=["N06AA09", "N06AA04", "N06AA02", "N06AA10", "N06AA16"],
+        atc_code="N06AA",
         load_prescribed=True,
         load_administered=True,
-        wildcard_code=False,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("selected_nassa")
+def selected_nassa(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code=["N06AX11", "N06AX03"],
+        load_prescribed=True,
+        load_administered=True,
+        wildcard_code=True,
         n_rows=n_rows,
     )
 
@@ -293,6 +363,28 @@ def lithium(n_rows: Optional[int] = None) -> pd.DataFrame:
     )
 
 
+@data_loaders.register("valproate")
+def valproate(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="N03AG01",
+        load_prescribed=True,
+        load_administered=True,
+        wildcard_code=False,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("lamotrigine")
+def lamotrigine(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="N03AX09",
+        load_prescribed=True,
+        load_administered=True,
+        wildcard_code=False,
+        n_rows=n_rows,
+    )
+
+
 @data_loaders.register("hyperactive disorders medications")
 def hyperactive_disorders_medications(n_rows: Optional[int] = None) -> pd.DataFrame:
     return load(
@@ -502,3 +594,48 @@ def various_medications(n_rows: Optional[int] = None) -> pd.DataFrame:
         wildcard_code=True,
         n_rows=n_rows,
     )
+
+
+@data_loaders.register("statins")
+def statins(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="C10AA",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("antihypertensives")
+def antihypertensives(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="C02",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("diuretics")
+def diuretics(n_rows: Optional[int] = None) -> pd.DataFrame:
+    return load(
+        atc_code="C07",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
+
+
+@data_loaders.register("gerd_drugs")
+def gerd_drugs(n_rows: Optional[int] = None) -> pd.DataFrame:
+    """Gastroesophageal reflux disease (GERD) drugs"""
+    return load(
+        atc_code="A02",
+        load_prescribed=False,
+        load_administered=True,
+        wildcard_code=True,
+        n_rows=n_rows,
+    )
